Package: dynamAedes
Version: 2.2.9
Date: 2024-03-12
Title: A Unified Mechanistic Model for the Population Dynamics of
        Invasive Aedes Mosquitoes
Authors@R: c(person("Matteo", "Marcantonio", role = c("aut", "cre"), email = "marcantoniomatteo@gmail.com"),person("Daniele", "Da Re", role = c("aut"), email = "dare.daniele@gmail.com")) 
Depends: R (>= 4.0.0)
Imports: abind, doParallel, drc, foreach, geosphere, methods, parallel,
        terra
BugReports: https://github.com/mattmar/dynamAedes
Description: Generalised model for population dynamics of invasive Aedes mosquitoes. Rationale and model structure are described here: Da Re et al. (2021) <doi:10.1016/j.ecoinf.2020.101180> and Da Re et al. (2022) <doi:10.1101/2021.12.21.473628>.
VignetteBuilder: knitr
Encoding: UTF-8
Language: en-GB
LazyData: true
License: GPL (>= 2)
RoxygenNote: 7.3.1
Suggests: rmarkdown, knitr, eesim, gstat, stats, ggplot2, dplyr,
        lubridate, stringr
Config/testthat/edition: 3
URL: https://mattmar.github.io/dynamAedes/
NeedsCompilation: no
Packaged: 2024-03-12 21:27:03 UTC; matteo
Author: Matteo Marcantonio [aut, cre],
  Daniele Da Re [aut]
Maintainer: Matteo Marcantonio <marcantoniomatteo@gmail.com>
Repository: CRAN
Date/Publication: 2024-03-12 22:10:02 UTC
Built: R 4.2.3; ; 2024-03-14 23:14:27 UTC; unix
