#####################################
##               Import            ##
#####################################
importFrom("parallel", "makeCluster", "stopCluster", "mclapply")
importFrom("doParallel", "registerDoParallel")
importFrom("foreach", "%dopar%", "foreach", "%do%")
importFrom("utils", "setTxtProgressBar", "txtProgressBar")
importFrom("stats", "dgamma", "dlnorm", "lm", "predict", "rbinom", "rmultinom", "rpois", "sortedXyData", "quantile", "setNames", "glm")
importFrom("drc", "drm")
importFrom("geosphere", "daylength")
importFrom("terra", "distance","crds","project","vect","rast")
importFrom("abind", "abind")
importFrom("methods", "new")

#####################################
##               Export            ##
#####################################

export(adci)
export(dici)
export(dynamAedes.m)
export(icci)
export(psi)
export(psi_sp)
export(spreader)
